
<p align="center">
  <img src="https://user-images.githubusercontent.com/84760072/227747904-eaf84b81-3b85-4b39-8016-69e9c7aae641.png" width=450/>
</p>

<p align="center">
  A stylish, minimalistic, ChatGPT-infused command-line interface 
</p>


<p align="center">
  <img src="https://user-images.githubusercontent.com/84760072/227741638-b997b164-98b8-494a-8c23-502525488f73.png" width=900/>
</p>

<p align="center">
	<a href="https://github.com/hwelsters/sleepychat/stargazers">
		<img alt="Stargazers" src="https://img.shields.io/github/stars/hwelsters/pou?style=for-the-badge&logo=starship&color=f9e1cb&logoColor=ffffff&labelColor=342430"></a>
	<a href="https://github.com/hwelsters/pou/releases/latest">
		<img alt="Releases" src="https://img.shields.io/github/release/hwelsters/pou.svg?style=for-the-badge&logo=github&color=f9e1cb&logoColor=ffffff&labelColor=342430"/></a>
	<a href="https://github.com/hwelsters/pou/issues">
		<img alt="Issues" src="https://img.shields.io/github/issues/hwelsters/pou?style=for-the-badge&logo=gitbook&color=f9e1cb&logoColor=ffffff&labelColor=342430"></a>
</p>


## Install as a Python Library
```
py -m pip install pou
```

## Run in terminal
```
py -m pou
```

## Configure settings
![sleepychat-settings-text](https://user-images.githubusercontent.com/84760072/227746507-99a530a9-d85b-4801-8080-f5ee1005f4e1.gif)


## Samples
```
ask 'Say something cool and amazing'
```
![sleepychat-ask](https://user-images.githubusercontent.com/84760072/227746462-32b33347-cb30-4e10-ad83-1e8dd42b2c33.gif)
  
```
translate indonesian 'Hello, how are you?'
```
![sleepychat-translate](https://user-images.githubusercontent.com/84760072/227746483-2941b705-95d1-4f1e-bf5c-530614b6537a.gif)



## Get involved
- 🐛 **Found a bug or interested in adding a feature?** - Create an [issue][issue]  
- 🤗 **Want to help?** - Create a pull-request!

[issue]: https://github.com/hwelsters/pou/issues
